Module walker

Module walker 

Graph walker for dependency traversal.

Performs BFS traversal of the import graph, parsing modules and building a CollectionState that can be converted to a ModuleGraph.

Structs

GraphWalker
Graph walker that traverses the dependency graph.
PathTraversalError
Error indicating a path traversal attempt was detected.

Enums

WalkerError
Error that can occur during graph walking.

Functions

normalize_and_validate_path
Normalize a path and validate it stays within the cwd.
validate_path_within_cwd
Validate that a normalized path stays within the current working directory.