pub struct ChainAnalysis {
pub target: ModuleId,
pub chains: Vec<DependencyChain>,
pub min_depth: Option<usize>,
pub max_depth: Option<usize>,
pub avg_depth: f64,
pub entry_point_count: usize,
}Expand description
Analysis of all dependency chains to a module.
Fields
target: ModuleIdTarget module being analyzed
chains: Vec<DependencyChain>All chains leading to this module
min_depth: Option<usize>Shortest chain depth
max_depth: Option<usize>Longest chain depth
avg_depth: f64Average chain depth
entry_point_count: usizeNumber of unique entry points that reach this module
Implementations
Sourceimpl ChainAnalysis
impl ChainAnalysis
Sourcepub fn from_chains(target: ModuleId, chains: Vec<DependencyChain>) -> Self
pub fn from_chains(target: ModuleId, chains: Vec<DependencyChain>) -> Self
Create chain analysis from a collection of chains.
Sourcepub fn is_reachable(&self) -> bool
pub fn is_reachable(&self) -> bool
Check if the module is reachable from any entry point.
Sourcepub fn shortest_chain(&self) -> Option<&DependencyChain>
pub fn shortest_chain(&self) -> Option<&DependencyChain>
Get the shortest chain (if any).
Sourcepub fn circular_chains(&self) -> Vec<&DependencyChain>
pub fn circular_chains(&self) -> Vec<&DependencyChain>
Get all chains containing cycles.