#[repr(C, u8)]pub enum BindingPatternKind<'a> {
BindingIdentifier(Box<'a, BindingIdentifier<'a>>),
ObjectPattern(Box<'a, ObjectPattern<'a>>),
ArrayPattern(Box<'a, ArrayPattern<'a>>),
AssignmentPattern(Box<'a, AssignmentPattern<'a>>),
}Variants
BindingIdentifier(Box<'a, BindingIdentifier<'a>>)
x in const x = 1;.
Also e.g. x in:
const [x] = arr;const { a: x } = obj;const [ ...x ] = arr;const [x = 1] = arr;function f(x) {}try {} catch (x) {}
ObjectPattern(Box<'a, ObjectPattern<'a>>)
{x} in const {x} = 1;.
Also e.g. {x} in:
const [{x}] = arr;const { a: {x} } = obj;const [{x} = obj] = arr;const [ ...{x} ] = arr;function f({x}) {}try {} catch ({x}) {}
ArrayPattern(Box<'a, ArrayPattern<'a>>)
[x] in const [x] = 1;
Also e.g. [x] in:
const { a: [x] } = obj;const { a: [x] = arr } = obj;const [[x]] = obj;const [ ...[x] ] = arr;function f([x]) {}try {} catch ([x]) {}
AssignmentPattern(Box<'a, AssignmentPattern<'a>>)
x = 1 in const {x = 1} = obj;.
Also e.g. x = 1 in:
const [x = 1] = arr;const { a: x = 1 } = obj;function f(x = 1) {}
Also e.g. {x} = obj in:
const [{x} = obj] = arr;const { a: {x} = obj2 } = obj;function f({x} = obj) {}
Invalid in:
BindingRestElemente.g.const [...x = 1] = arr;.CatchParametere.g.try {} catch (e = 1) {}.
Implementations
Sourceimpl<'a> BindingPatternKind<'a>
impl<'a> BindingPatternKind<'a>
Sourcepub fn get_identifier_name(&self) -> Option<Atom<'a>>
pub fn get_identifier_name(&self) -> Option<Atom<'a>>
Returns the name of the bound identifier in this binding pattern, if it has one, or None otherwise.
Example
- calling on
a = 1inlet a = 1would returnSome("a") - calling on
a = 1inlet {a = 1} = cwould returnSome("a") - calling on
a: binlet {a: b} = cwould returnNone
Sourcepub fn get_binding_identifier(&self) -> Option<&BindingIdentifier<'a>>
pub fn get_binding_identifier(&self) -> Option<&BindingIdentifier<'a>>
Returns the bound identifier in this binding pattern, if it has one, or None otherwise.
To just get the name of the bound identifier, use BindingPatternKind::get_identifier_name.
Example
- calling on
a = 1inlet a = 1would returnSome(BindingIdentifier { name: "a", .. }) - calling on
a = 1inlet {a = 1} = cwould returnSome(BindingIdentifier { name: "a", .. }) - calling on
a: binlet {a: b} = cwould returnNone
Sourcepub fn get_binding_identifiers(&self) -> Vec<&BindingIdentifier<'a>>
pub fn get_binding_identifiers(&self) -> Vec<&BindingIdentifier<'a>>
Returns the bound identifiers in this binding pattern.
Example
let {} = objwould return[]let {a, b} = objwould return[a, b]let {a = 1, b: c} = objwould return[a, c]
Sourcepub fn is_destructuring_pattern(&self) -> bool
pub fn is_destructuring_pattern(&self) -> bool
Returns true if this binding pattern is destructuring.
Example
{a, b}inlet {a, b} = objwould returntrue[a, b]inlet [a, b] = arrwould returntruea = 1inlet {a = 1} = objwould returntrueainlet {a = 1} = objwould returnfalse
Sourcepub fn is_binding_identifier(&self) -> bool
pub fn is_binding_identifier(&self) -> bool
Returns true if this binding pattern is a binding identifier like a in let a = 1.
Sourcepub fn is_object_pattern(&self) -> bool
pub fn is_object_pattern(&self) -> bool
Returns true if this binding pattern is an object pattern like {a} in let {a} = obj.
Sourcepub fn is_array_pattern(&self) -> bool
pub fn is_array_pattern(&self) -> bool
Returns true if this binding pattern is an array pattern like [a] in let [a] = arr.
Sourcepub fn is_assignment_pattern(&self) -> bool
pub fn is_assignment_pattern(&self) -> bool
Returns true if this binding pattern is an assignment pattern like a = 1 in let {a = 1} = obj.