#[repr(C, u8)]pub enum ClassElement<'a> {
StaticBlock(Box<'a, StaticBlock<'a>>),
MethodDefinition(Box<'a, MethodDefinition<'a>>),
PropertyDefinition(Box<'a, PropertyDefinition<'a>>),
AccessorProperty(Box<'a, AccessorProperty<'a>>),
TSIndexSignature(Box<'a, TSIndexSignature<'a>>),
}Expand description
Class Body Element
Example
class Foo {
[prop: string]: string // ClassElement::TSIndexSignature
public x: number // ClassElement::PropertyDefinition
accessor z() { return 5 } // ClassElement::AccessorProperty
// These are all ClassElement::MethodDefinitions
get y() { return 5 }
set y(value) { }
static foo() {}
bar() {}
}Variants
StaticBlock(Box<'a, StaticBlock<'a>>)
MethodDefinition(Box<'a, MethodDefinition<'a>>)
Class Methods
Includes static and non-static methods, constructors, getters, and setters.
PropertyDefinition(Box<'a, PropertyDefinition<'a>>)
AccessorProperty(Box<'a, AccessorProperty<'a>>)
TSIndexSignature(Box<'a, TSIndexSignature<'a>>)
Implementations
Sourceimpl<'a> ClassElement<'a>
impl<'a> ClassElement<'a>
Sourcepub fn is_static_block(&self) -> bool
pub fn is_static_block(&self) -> bool
Returns true if this is a ClassElement::StaticBlock.
Sourcepub fn static(&self) -> bool
pub fn static(&self) -> bool
Returns true if this ClassElement has a static modifier.
Note: Class static blocks do not have a “modifier”, as there is no non-static equivalent.
Therefore, returns false for static blocks.
The following all return true:
class {
static prop = 1;
static method() {}
static #private = 2;
static #privateMethod() {}
static accessor accessorProp = 3;
static accessor #privateAccessorProp = 4;
}Sourcepub fn computed(&self) -> bool
pub fn computed(&self) -> bool
Returns true if this ClassElement is computed.
The following all return true:
class C {
[a] = 1;
[b]() {}
accessor [c] = 2;
}Sourcepub fn accessibility(&self) -> Option<TSAccessibility>
pub fn accessibility(&self) -> Option<TSAccessibility>
Returns the accessibility of this ClassElement, if any is indicated.
Sourcepub fn method_definition_kind(&self) -> Option<MethodDefinitionKind>
pub fn method_definition_kind(&self) -> Option<MethodDefinitionKind>
Returns whether this ClassElement method is a constructor, method, getter, or setter,
or None otherwise if it is not a method definition.
Sourcepub fn property_key(&self) -> Option<&PropertyKey<'a>>
pub fn property_key(&self) -> Option<&PropertyKey<'a>>
Returns the PropertyKey of this ClassElement, if any.
This is either the name of the method, property name, or accessor name.
Sourcepub fn static_name(&self) -> Option<Cow<'a, str>>
pub fn static_name(&self) -> Option<Cow<'a, str>>
Try to get the statically known name of this ClassElement. Handles
computed members that use literals.
Sourcepub fn is_property(&self) -> bool
pub fn is_property(&self) -> bool
Returns true if this ClassElement is a property or accessor
Sourcepub fn is_ts_empty_body_function(&self) -> bool
pub fn is_ts_empty_body_function(&self) -> bool
true for overloads, declarations, index signatures, and abstract
methods, etc. That is, any non-concrete implementation.
Sourcepub fn is_typescript_syntax(&self) -> bool
pub fn is_typescript_syntax(&self) -> bool
Returns true if this class element uses any TypeScript syntax such as index signatures (like [key: string]: any),
abstract properties, function overload signatures, or declare.
Sourcepub fn has_decorator(&self) -> bool
pub fn has_decorator(&self) -> bool
true for decorated class elements.
Sourcepub fn is_abstract(&self) -> bool
pub fn is_abstract(&self) -> bool
Has this property been marked as abstract?
abstract class Foo { // <-- not considered
foo: string; // <-- false
abstract bar: string; // <-- true
}Trait Implementations
Sourceimpl<'new_alloc> CloneIn<'new_alloc> for ClassElement<'_>
impl<'new_alloc> CloneIn<'new_alloc> for ClassElement<'_>
Sourcetype Cloned = ClassElement<'new_alloc>
type Cloned = ClassElement<'new_alloc>
Sourcefn clone_in(
&self,
allocator: &'new_alloc Allocator,
) -> <ClassElement<'_> as CloneIn<'new_alloc>>::Cloned
fn clone_in( &self, allocator: &'new_alloc Allocator, ) -> <ClassElement<'_> as CloneIn<'new_alloc>>::Cloned
self into the given allocator. allocator may be the same one
that self is already in.Sourcefn clone_in_with_semantic_ids(
&self,
allocator: &'new_alloc Allocator,
) -> <ClassElement<'_> as CloneIn<'new_alloc>>::Cloned
fn clone_in_with_semantic_ids( &self, allocator: &'new_alloc Allocator, ) -> <ClassElement<'_> as CloneIn<'new_alloc>>::Cloned
clone_in, but for some special type, it will also clone the semantic ids.
Please use this method only if you make sure semantic info is synced with the ast node.Sourceimpl ContentEq for ClassElement<'_>
impl ContentEq for ClassElement<'_>
Sourcefn content_eq(&self, other: &ClassElement<'_>) -> bool
fn content_eq(&self, other: &ClassElement<'_>) -> bool
self and other to be equal.Sourcefn content_ne(&self, other: &Self) -> bool
fn content_ne(&self, other: &Self) -> bool
self and other not to be equal.
The default implementation is almost always
sufficient, and should not be overridden without very good reason.Sourceimpl<'a> Debug for ClassElement<'a>
impl<'a> Debug for ClassElement<'a>
Sourceimpl<'a> Dummy<'a> for ClassElement<'a>
impl<'a> Dummy<'a> for ClassElement<'a>
Sourcefn dummy(allocator: &'a Allocator) -> ClassElement<'a>
fn dummy(allocator: &'a Allocator) -> ClassElement<'a>
Create a dummy ClassElement.
Has cost of making 1 allocation (40 bytes).
Sourceimpl Gen for ClassElement<'_>
impl Gen for ClassElement<'_>
Sourceimpl GetAddress for ClassElement<'_>
impl GetAddress for ClassElement<'_>
Sourceimpl GetSpanMut for ClassElement<'_>
impl GetSpanMut for ClassElement<'_>
Sourceimpl<'a> MayHaveSideEffects<'a> for ClassElement<'a>
impl<'a> MayHaveSideEffects<'a> for ClassElement<'a>
fn may_have_side_effects( &self, ctx: &impl MayHaveSideEffectsContext<'a>, ) -> bool
Sourceimpl PrivateBoundIdentifiers for ClassElement<'_>
impl PrivateBoundIdentifiers for ClassElement<'_>
fn private_bound_identifiers(&self) -> Option<PrivateIdentifier<'_>>
Sourceimpl<'a> TakeIn<'a> for ClassElement<'a>
impl<'a> TakeIn<'a> for ClassElement<'a>
Sourcefn take_in<A>(&mut self, allocator_accessor: A) -> Selfwhere
A: AllocatorAccessor<'a>,
fn take_in<A>(&mut self, allocator_accessor: A) -> Selfwhere
A: AllocatorAccessor<'a>,
Sourcefn take_in_box<A>(&mut self, allocator_accessor: A) -> Box<'a, Self>where
A: AllocatorAccessor<'a>,
fn take_in_box<A>(&mut self, allocator_accessor: A) -> Box<'a, Self>where
A: AllocatorAccessor<'a>,