Declaration

Enum Declaration 

#[repr(C, u8)]
pub enum Declaration<'a> { VariableDeclaration(Box<'a, VariableDeclaration<'a>>), FunctionDeclaration(Box<'a, Function<'a>>), ClassDeclaration(Box<'a, Class<'a>>), TSTypeAliasDeclaration(Box<'a, TSTypeAliasDeclaration<'a>>), TSInterfaceDeclaration(Box<'a, TSInterfaceDeclaration<'a>>), TSEnumDeclaration(Box<'a, TSEnumDeclaration<'a>>), TSModuleDeclaration(Box<'a, TSModuleDeclaration<'a>>), TSImportEqualsDeclaration(Box<'a, TSImportEqualsDeclaration<'a>>), }
Declarations and the Variable Statement

Variants



VariableDeclaration(Box<'a, VariableDeclaration<'a>>)



FunctionDeclaration(Box<'a, Function<'a>>)



ClassDeclaration(Box<'a, Class<'a>>)



TSTypeAliasDeclaration(Box<'a, TSTypeAliasDeclaration<'a>>)



TSInterfaceDeclaration(Box<'a, TSInterfaceDeclaration<'a>>)



TSEnumDeclaration(Box<'a, TSEnumDeclaration<'a>>)



TSModuleDeclaration(Box<'a, TSModuleDeclaration<'a>>)



TSImportEqualsDeclaration(Box<'a, TSImportEqualsDeclaration<'a>>)

Implementations

Source

impl<'a> Declaration<'a>

pub fn is_typescript_syntax(&self) -> bool

Returns true if this declaration uses any TypeScript syntax such as declare, abstract classes, or function overload signatures.

pub fn id(&self) -> Option<&BindingIdentifier<'a>>

Get the identifier bound by this declaration.

Example
const x = 1; // None. may change in the future.
class Foo {} // Some(IdentifierReference { name: "Foo", .. })
enum Bar {} // Some(IdentifierReference { name: "Bar", .. })
pub fn declare(&self) -> bool

Returns true if this declaration was made using the declare keyword in TypeScript.

pub fn is_type(&self) -> bool

Returns true if this declaration is a TypeScript type or interface declaration.