#[repr(C)]pub struct ArrowFunctionExpression<'a> {
pub span: Span,
pub type_parameters: Option<Box<'a, TSTypeParameterDeclaration<'a>>>,
pub params: Box<'a, FormalParameters<'a>>,
pub return_type: Option<Box<'a, TSTypeAnnotation<'a>>>,
pub body: Box<'a, FunctionBody<'a>>,
pub scope_id: Cell<Option<ScopeId>>,
pub expression: bool,
pub async: bool,
pub pure: bool,
pub pife: bool,
}Expand description
Arrow Function Definitions
Fields
span: Spantype_parameters: Option<Box<'a, TSTypeParameterDeclaration<'a>>>params: Box<'a, FormalParameters<'a>>return_type: Option<Box<'a, TSTypeAnnotation<'a>>>body: Box<'a, FunctionBody<'a>>See expression for whether this arrow expression returns an expression.
scope_id: Cell<Option<ScopeId>>expression: boolIs the function body an arrow expression? i.e. () => expr instead of () => {}
async: boolpure: booltrue if the function is marked with a /*#__NO_SIDE_EFFECTS__*/ comment
pife: booltrue if the function should be marked as “Possibly-Invoked Function Expression” (PIFE).
References:
- v8 blog post about PIFEs: https://v8.dev/blog/preparser#pife
- introduced PR: https://github.com/oxc-project/oxc/pull/12353
Implementations
Sourceimpl<'a> ArrowFunctionExpression<'a>
impl<'a> ArrowFunctionExpression<'a>
Sourcepub fn get_expression(&self) -> Option<&Expression<'a>>
pub fn get_expression(&self) -> Option<&Expression<'a>>
Get expression part of ArrowFunctionExpression: () => expression_part.
Sourcepub fn get_expression_mut(&mut self) -> Option<&mut Expression<'a>>
pub fn get_expression_mut(&mut self) -> Option<&mut Expression<'a>>
Get expression part of ArrowFunctionExpression: () => expression_part.
Sourcepub fn has_use_strict_directive(&self) -> bool
pub fn has_use_strict_directive(&self) -> bool
Returns true if this arrow function’s body has a "use strict" directive.
Sourceimpl ArrowFunctionExpression<'_>
impl ArrowFunctionExpression<'_>
Sourcepub fn scope_id(&self) -> ScopeId
pub fn scope_id(&self) -> ScopeId
Get ScopeId of ArrowFunctionExpression.
Only use this method on a post-semantic AST where ScopeIds are always defined.
Panics
Panics if scope_id is None.
Sourcepub fn set_scope_id(&self, scope_id: ScopeId)
pub fn set_scope_id(&self, scope_id: ScopeId)
Set ScopeId of ArrowFunctionExpression.