#[repr(C)]pub struct BinaryExpression<'a> {
pub span: Span,
pub left: Expression<'a>,
pub right: Expression<'a>,
pub operator: BinaryOperator,
}Expand description
1 + 1 in const two = 1 + 1;
Represents a binary expression, which include a left expression, an operator, and a right expression.
Fields
span: Spanleft: Expression<'a>right: Expression<'a>operator: BinaryOperatorTrait Implementations
Sourceimpl<'new_alloc> CloneIn<'new_alloc> for BinaryExpression<'_>
impl<'new_alloc> CloneIn<'new_alloc> for BinaryExpression<'_>
Sourcetype Cloned = BinaryExpression<'new_alloc>
type Cloned = BinaryExpression<'new_alloc>
The type of the cloned object. Read more
Sourcefn clone_in(
&self,
allocator: &'new_alloc Allocator,
) -> <BinaryExpression<'_> as CloneIn<'new_alloc>>::Cloned
fn clone_in( &self, allocator: &'new_alloc Allocator, ) -> <BinaryExpression<'_> as CloneIn<'new_alloc>>::Cloned
Clone
self into the given allocator. allocator may be the same one
that self is already in.Sourcefn clone_in_with_semantic_ids(
&self,
allocator: &'new_alloc Allocator,
) -> <BinaryExpression<'_> as CloneIn<'new_alloc>>::Cloned
fn clone_in_with_semantic_ids( &self, allocator: &'new_alloc Allocator, ) -> <BinaryExpression<'_> as CloneIn<'new_alloc>>::Cloned
Almost identical as
clone_in, but for some special type, it will also clone the semantic ids.
Please use this method only if you make sure semantic info is synced with the ast node.Sourceimpl<'a> ConstantEvaluation<'a> for BinaryExpression<'a>
impl<'a> ConstantEvaluation<'a> for BinaryExpression<'a>
Sourcefn evaluate_value_to(
&self,
ctx: &impl ConstantEvaluationCtx<'a>,
target_ty: Option<ValueType>,
) -> Option<ConstantValue<'a>>
fn evaluate_value_to( &self, ctx: &impl ConstantEvaluationCtx<'a>, target_ty: Option<ValueType>, ) -> Option<ConstantValue<'a>>
Evaluate the expression to a constant value. Read more
Sourcefn evaluate_value(
&self,
ctx: &impl ConstantEvaluationCtx<'a>,
) -> Option<ConstantValue<'a>>
fn evaluate_value( &self, ctx: &impl ConstantEvaluationCtx<'a>, ) -> Option<ConstantValue<'a>>
Evaluate the expression to a constant value. Read more
Sourcefn evaluate_value_to_number(
&self,
ctx: &impl ConstantEvaluationCtx<'a>,
) -> Option<f64>
fn evaluate_value_to_number( &self, ctx: &impl ConstantEvaluationCtx<'a>, ) -> Option<f64>
Evaluate the expression to a constant value and convert it to a number.
Sourcefn evaluate_value_to_bigint(
&self,
ctx: &impl ConstantEvaluationCtx<'a>,
) -> Option<BigInt>
fn evaluate_value_to_bigint( &self, ctx: &impl ConstantEvaluationCtx<'a>, ) -> Option<BigInt>
Evaluate the expression to a constant value and convert it to a bigint.
Sourcefn evaluate_value_to_boolean(
&self,
ctx: &impl ConstantEvaluationCtx<'a>,
) -> Option<bool>
fn evaluate_value_to_boolean( &self, ctx: &impl ConstantEvaluationCtx<'a>, ) -> Option<bool>
Evaluate the expression to a constant value and convert it to a boolean.
Sourcefn evaluate_value_to_string(
&self,
ctx: &impl ConstantEvaluationCtx<'a>,
) -> Option<Cow<'a, str>>
fn evaluate_value_to_string( &self, ctx: &impl ConstantEvaluationCtx<'a>, ) -> Option<Cow<'a, str>>
Evaluate the expression to a constant value and convert it to a string.
fn get_side_free_number_value( &self, ctx: &impl ConstantEvaluationCtx<'a>, ) -> Option<f64>
fn get_side_free_bigint_value( &self, ctx: &impl ConstantEvaluationCtx<'a>, ) -> Option<BigInt>
fn get_side_free_boolean_value( &self, ctx: &impl ConstantEvaluationCtx<'a>, ) -> Option<bool>
fn get_side_free_string_value( &self, ctx: &impl ConstantEvaluationCtx<'a>, ) -> Option<Cow<'a, str>>
Sourceimpl ContentEq for BinaryExpression<'_>
impl ContentEq for BinaryExpression<'_>
Sourcefn content_eq(&self, other: &BinaryExpression<'_>) -> bool
fn content_eq(&self, other: &BinaryExpression<'_>) -> bool
This method tests for contents of
self and other to be equal.Sourcefn content_ne(&self, other: &Self) -> bool
fn content_ne(&self, other: &Self) -> bool
This method tests for contents of
self and other not to be equal.
The default implementation is almost always
sufficient, and should not be overridden without very good reason.Sourceimpl<'a> Debug for BinaryExpression<'a>
impl<'a> Debug for BinaryExpression<'a>
Sourceimpl<'a> DetermineValueType<'a> for BinaryExpression<'a>
impl<'a> DetermineValueType<'a> for BinaryExpression<'a>
fn value_type(&self, ctx: &impl GlobalContext<'a>) -> ValueType
Sourceimpl<'a> Dummy<'a> for BinaryExpression<'a>
impl<'a> Dummy<'a> for BinaryExpression<'a>
Sourcefn dummy(allocator: &'a Allocator) -> BinaryExpression<'a>
fn dummy(allocator: &'a Allocator) -> BinaryExpression<'a>
Create a dummy BinaryExpression.
Has cost of making 2 allocations (16 bytes).
Sourceimpl GenExpr for BinaryExpression<'_>
impl GenExpr for BinaryExpression<'_>
Sourcefn gen_expr(&self, p: &mut Codegen<'_>, precedence: Precedence, ctx: Context)
fn gen_expr(&self, p: &mut Codegen<'_>, precedence: Precedence, ctx: Context)
Generate code for an expression, respecting operator precedence.
Sourcefn print_expr(&self, p: &mut Codegen<'_>, precedence: Precedence, ctx: Context)
fn print_expr(&self, p: &mut Codegen<'_>, precedence: Precedence, ctx: Context)
Generate code for an expression, respecting operator precedence. Alias for
gen_expr.Sourceimpl GetPrecedence for BinaryExpression<'_>
impl GetPrecedence for BinaryExpression<'_>
fn precedence(&self) -> Precedence
Sourceimpl GetSpan for BinaryExpression<'_>
impl GetSpan for BinaryExpression<'_>
Sourceimpl GetSpanMut for BinaryExpression<'_>
impl GetSpanMut for BinaryExpression<'_>
Sourceimpl<'a> IsInt32OrUint32<'a> for BinaryExpression<'a>
impl<'a> IsInt32OrUint32<'a> for BinaryExpression<'a>
Sourcefn is_int32_or_uint32(&self, ctx: &impl GlobalContext<'a>) -> bool
fn is_int32_or_uint32(&self, ctx: &impl GlobalContext<'a>) -> bool
Whether the value of the expression is a int32 or uint32.
If this method returns
true, we know that the value cannot be NaN or Infinity. Read moreSourceimpl<'a> IsLiteralValue<'a, '_> for BinaryExpression<'a>
impl<'a> IsLiteralValue<'a, '_> for BinaryExpression<'a>
fn is_literal_value( &self, include_functions: bool, ctx: &impl GlobalContext<'a>, ) -> bool
Sourceimpl<'a> MayHaveSideEffects<'a> for BinaryExpression<'a>
impl<'a> MayHaveSideEffects<'a> for BinaryExpression<'a>
fn may_have_side_effects( &self, ctx: &impl MayHaveSideEffectsContext<'a>, ) -> bool
Sourceimpl<'a> TakeIn<'a> for BinaryExpression<'a>
impl<'a> TakeIn<'a> for BinaryExpression<'a>
Sourcefn take_in<A>(&mut self, allocator_accessor: A) -> Selfwhere
A: AllocatorAccessor<'a>,
fn take_in<A>(&mut self, allocator_accessor: A) -> Selfwhere
A: AllocatorAccessor<'a>,
Replace node with a dummy.
Sourcefn take_in_box<A>(&mut self, allocator_accessor: A) -> Box<'a, Self>where
A: AllocatorAccessor<'a>,
fn take_in_box<A>(&mut self, allocator_accessor: A) -> Box<'a, Self>where
A: AllocatorAccessor<'a>,
Replace node with a boxed dummy.
Sourceimpl UnstableAddress for BinaryExpression<'_>
impl UnstableAddress for BinaryExpression<'_>