#[repr(C)]pub struct BindingIdentifier<'a> {
pub span: Span,
pub name: Atom<'a>,
pub symbol_id: Cell<Option<SymbolId>>,
}Expand description
x in const x = 0;
Represents a binding identifier, which is an identifier that is used to declare a variable, function, class, or object.
See: 13.1 Identifiers
Also see other examples in docs for BindingPatternKind.
Fields
span: Spanname: Atom<'a>The identifier name being bound.
symbol_id: Cell<Option<SymbolId>>Unique identifier for this binding.
This gets initialized during semantic analysis in the bind step. If
you choose to skip semantic analysis, this will always be None.
Implementations
Sourceimpl BindingIdentifier<'_>
impl BindingIdentifier<'_>
Sourcepub fn symbol_id(&self) -> SymbolId
pub fn symbol_id(&self) -> SymbolId
Get SymbolId of BindingIdentifier.
Only use this method on a post-semantic AST where SymbolIds are always defined.
Panics
Panics if symbol_id is None.
Sourcepub fn set_symbol_id(&self, symbol_id: SymbolId)
pub fn set_symbol_id(&self, symbol_id: SymbolId)
Set SymbolId of BindingIdentifier.