BindingPattern

Struct BindingPattern 

#[repr(C)]
pub struct BindingPattern<'a> { pub kind: BindingPatternKind<'a>, pub type_annotation: Option<Box<'a, TSTypeAnnotation<'a>>>, pub optional: bool, }
Destructuring Binding Patterns. https://tc39.es/ecma262/#prod-BindingPattern

Binding patterns can be nested within other binding patterns e.g. const [ { a: [ {x} ] } ] = arr;.

Type annotations are valid in some positions e.g. const x: T = f(); but invalid in others e.g. const [x: T] = f();.

Fields

kind: BindingPatternKind<'a>type_annotation: Option<Box<'a, TSTypeAnnotation<'a>>>optional: bool

Implementations

Source

impl<'a> BindingPattern<'a>

pub fn get_identifier_name(&self) -> Option<Atom<'a>>

Returns the name of the bound identifier in this binding pattern, if it has one, or None otherwise.

Example
  • calling on a = 1 in let a = 1 would return Some("a")
  • calling on a = 1 in let {a = 1} = c would return Some("a")
  • calling on a: b in let {a: b} = c would return None
pub fn get_binding_identifier(&self) -> Option<&BindingIdentifier<'a>>

Returns the bound identifier in this binding pattern, if it has one, or None otherwise.

To just get the name of the bound identifier, use BindingPattern::get_identifier_name.

Example
  • calling on a = 1 in let a = 1 would return Some(BindingIdentifier { name: "a", .. })
  • calling on a = 1 in let {a = 1} = c would return Some(BindingIdentifier { name: "a", .. })
  • calling on a: b in let {a: b} = c would return None
pub fn get_binding_identifiers(&self) -> Vec<&BindingIdentifier<'a>>

Returns the bound identifiers in this binding pattern.

Example
  • let {} = obj would return []
  • let {a, b} = obj would return [a, b]
  • let {a = 1, b: c} = obj would return [a, c]