CallExpression

Struct CallExpression 

#[repr(C)]
pub struct CallExpression<'a> { pub span: Span, pub callee: Expression<'a>, pub type_arguments: Option<Box<'a, TSTypeParameterInstantiation<'a>>>, pub arguments: Vec<'a, Argument<'a>>, pub optional: bool, pub pure: bool, }
foo() in function foo() { return 1; }; foo();

Represents a call expression, which can include a callee and arguments.

Examples

//        ___ callee
const x = foo(1, 2)

//            ^^^^ arguments
const y = foo.bar?.(1, 2)
//               ^ optional

const z = foo<number, string>(1, 2)
//            ^^^^^^^^^^^^^^ type_arguments

Fields

span: Spancallee: Expression<'a>type_arguments: Option<Box<'a, TSTypeParameterInstantiation<'a>>>arguments: Vec<'a, Argument<'a>>optional: boolpure: bool

true if the call expression is marked with a /* @__PURE__ */ comment

Implementations

Source

impl CallExpression<'_>

pub fn callee_name(&self) -> Option<&str>

Returns the static name of the callee, if it has one, or None otherwise.

pub fn is_require_call(&self) -> bool

Returns true if this CallExpression matches one of these patterns:

require('string')
require(`string`)
require(`foo${bar}qux`) // Any number of expressions and quasis
pub fn is_symbol_or_symbol_for_call(&self) -> bool

Returns true if this CallExpression is a call to Symbol or Symbol.for.

pub fn common_js_require(&self) -> Option<&StringLiteral<'_>>

Returns true if this looks like a call to require in CommonJS (has a single string argument):

require('string') // => true
require('string', 'string') // => false
require() // => false
require(123) // => false
pub fn arguments_span(&self) -> Option<Span>

Returns the span covering all arguments in this call expression.

The span starts at the beginning of the first argument and ends at the end of the last argument (inclusive).

Examples
foo(bar, baz);
//  ^^^^^^^^  <- arguments_span() covers this range

If the call expression has no arguments, None is returned.