Comment

Struct Comment 

#[repr(C)]
pub struct Comment { pub span: Span, pub attached_to: u32, pub kind: CommentKind, pub position: CommentPosition, pub newlines: CommentNewlines, pub content: CommentContent, }
A comment in source code.

Fields

span: Span

The span of the comment text, with leading and trailing delimiters.

attached_to: u32

Start of token this leading comment is attached to. /* Leading */ token ^ This start NOTE: Trailing comment attachment is not computed yet.

kind: CommentKind

Line or block comment

position: CommentPosition

Leading or trailing comment

newlines: CommentNewlines

Whether this comment has newlines around it. Used to avoid becoming a trailing comment in codegen.

content: CommentContent

Content of the comment

Implementations

Source

impl Comment

pub fn new(start: u32, end: u32, kind: CommentKind) -> Comment

Create a line or block comment at a given location.

pub fn content_span(&self) -> Span

Gets the span of the comment content.

pub fn is_line(self) -> bool

Returns true if this is a line comment.

pub fn is_block(self) -> bool

Returns true if this is a block comment.

pub fn is_leading(self) -> bool

Returns true if this comment is before a token.

pub fn is_trailing(self) -> bool

Returns true if this comment is after a token.

pub fn is_normal(self) -> bool

Is comment without a special meaning.

pub fn is_annotation(self) -> bool

Is comment with special meaning.

pub fn is_jsdoc(self) -> bool

Returns true if this comment is a JSDoc comment. Implies is_leading and is_block.

Legal comments

A “legal comment” is considered to be any statement-level comment that contains @license or @preserve or that starts with //! or /*!.

https://esbuild.github.io/api/#legal-comments

pub fn is_pure(self) -> bool

Is /* @__PURE__*/.

pub fn is_no_side_effects(self) -> bool

Is /* @__NO_SIDE_EFFECTS__*/.

pub fn is_webpack(self) -> bool

Is webpack magic comment.

pub fn is_vite(self) -> bool

Is vite special comment.

pub fn is_coverage_ignore(self) -> bool

Is coverage ignore comment.

pub fn preceded_by_newline(self) -> bool

Returns true if this comment is preceded by a newline.

pub fn followed_by_newline(self) -> bool

Returns true if this comment is followed by a newline.

pub fn set_preceded_by_newline(&mut self, preceded_by_newline: bool)

Sets the state of newlines to include/exclude a newline before the comment.

pub fn set_followed_by_newline(&mut self, followed_by_newline: bool)

Sets the state of newlines to include/exclude a newline after the comment.