pub struct CommentNewlines(/* private fields */);Expand description
State of newlines around a comment.
Implementations
Sourceimpl CommentNewlines
impl CommentNewlines
Sourcepub const Leading: CommentNewlines
pub const Leading: CommentNewlines
Preceded by a newline
Sourcepub const Trailing: CommentNewlines
pub const Trailing: CommentNewlines
Followed by a newline
Sourcepub const None: CommentNewlines
pub const None: CommentNewlines
No newlines before or after
Sourceimpl CommentNewlines
impl CommentNewlines
Sourcepub const fn empty() -> CommentNewlines
pub const fn empty() -> CommentNewlines
Get a flags value with all bits unset.
Sourcepub const fn all() -> CommentNewlines
pub const fn all() -> CommentNewlines
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<CommentNewlines>
pub const fn from_bits(bits: u8) -> Option<CommentNewlines>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> CommentNewlines
pub const fn from_bits_truncate(bits: u8) -> CommentNewlines
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> CommentNewlines
pub const fn from_bits_retain(bits: u8) -> CommentNewlines
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<CommentNewlines>
pub fn from_name(name: &str) -> Option<CommentNewlines>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: CommentNewlines) -> bool
pub const fn intersects(&self, other: CommentNewlines) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: CommentNewlines) -> bool
pub const fn contains(&self, other: CommentNewlines) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: CommentNewlines)
pub fn insert(&mut self, other: CommentNewlines)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: CommentNewlines)
pub fn remove(&mut self, other: CommentNewlines)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: CommentNewlines)
pub fn toggle(&mut self, other: CommentNewlines)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: CommentNewlines, value: bool)
pub fn set(&mut self, other: CommentNewlines, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: CommentNewlines) -> CommentNewlines
pub const fn intersection(self, other: CommentNewlines) -> CommentNewlines
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: CommentNewlines) -> CommentNewlines
pub const fn union(self, other: CommentNewlines) -> CommentNewlines
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: CommentNewlines) -> CommentNewlines
pub const fn difference(self, other: CommentNewlines) -> CommentNewlines
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: CommentNewlines,
) -> CommentNewlines
pub const fn symmetric_difference( self, other: CommentNewlines, ) -> CommentNewlines
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> CommentNewlines
pub const fn complement(self) -> CommentNewlines
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl CommentNewlines
impl CommentNewlines
Sourcepub const fn iter(&self) -> Iter<CommentNewlines>
pub const fn iter(&self) -> Iter<CommentNewlines>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CommentNewlines>
pub const fn iter_names(&self) -> IterNames<CommentNewlines>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.