#[repr(C)]pub struct Function<'a> {Show 14 fields
pub span: Span,
pub id: Option<BindingIdentifier<'a>>,
pub type_parameters: Option<Box<'a, TSTypeParameterDeclaration<'a>>>,
pub this_param: Option<Box<'a, TSThisParameter<'a>>>,
pub params: Box<'a, FormalParameters<'a>>,
pub return_type: Option<Box<'a, TSTypeAnnotation<'a>>>,
pub body: Option<Box<'a, FunctionBody<'a>>>,
pub scope_id: Cell<Option<ScopeId>>,
pub type: FunctionType,
pub generator: bool,
pub async: bool,
pub declare: bool,
pub pure: bool,
pub pife: bool,
}Expand description
Function Statement or Expression
Includes generator functions and function-valued class properties.
Arrow functions are represented by ArrowFunctionExpression.
Examples
// id ___ ____ return_type
function foo(a: number): void {
// ^^^^^^^^^ params
console.log(a);
}// `async` and `generator` are true
async function* foo() {
yield 1;
}// function.id is None
// use function.r#type to check if a node is a function expression.
const foo = function() { }// Function overloads will not have a body
function add(a: number, b: number): number; // <-- No body
function add(a: string, b: string): string; // <-- No body
function add(a: any, b: any): any { // <-- Body is between `{}`, inclusive.
return a + b;
}Fields
span: Spanid: Option<BindingIdentifier<'a>>The function identifier. None for anonymous function expressions.
type_parameters: Option<Box<'a, TSTypeParameterDeclaration<'a>>>this_param: Option<Box<'a, TSThisParameter<'a>>>Declaring this in a Function https://www.typescriptlang.org/docs/handbook/2/functions.html#declaring-this-in-a-function
The JavaScript specification states that you cannot have a parameter called this,
and so TypeScript uses that syntax space to let you declare the type for this in the function body.
interface DB {
filterUsers(filter: (this: User) => boolean): User[];
// ^^^^
}
const db = getDB();
const admins = db.filterUsers(function (this: User) {
return this.admin;
});params: Box<'a, FormalParameters<'a>>Function parameters.
Does not include this parameters used by some TypeScript functions.
return_type: Option<Box<'a, TSTypeAnnotation<'a>>>The TypeScript return type annotation.
body: Option<Box<'a, FunctionBody<'a>>>The function body.
None for function declarations, e.g.
// TypeScript function declarations have no body
declare function foo(a: number): number;
function bar(a: number): number; // <- overloads have no body
function bar(a: number): number {
return a;
}scope_id: Cell<Option<ScopeId>>type: FunctionTypegenerator: boolIs this a generator function?
function* foo() { } // <- generator: true
function bar() { } // <- generator: falseasync: booldeclare: boolpure: booltrue if the function is marked with a /*#__NO_SIDE_EFFECTS__*/ comment
pife: booltrue if the function should be marked as “Possibly-Invoked Function Expression” (PIFE).
This only affects FunctionExpressions.
References:
- v8 blog post about PIFEs: https://v8.dev/blog/preparser#pife
- related PR: https://github.com/oxc-project/oxc/pull/12353
Implementations
Sourceimpl<'a> Function<'a>
impl<'a> Function<'a>
Sourcepub fn is_typescript_syntax(&self) -> bool
pub fn is_typescript_syntax(&self) -> bool
Returns true if this function uses overload signatures or declare function statements.
Sourcepub fn is_expression(&self) -> bool
pub fn is_expression(&self) -> bool
true for both function expressions and typescript empty body function expressions
Sourcepub fn is_function_declaration(&self) -> bool
pub fn is_function_declaration(&self) -> bool
true for function declarations
Sourcepub fn is_ts_declare_function(&self) -> bool
pub fn is_ts_declare_function(&self) -> bool
true for declare function statements
Sourcepub fn is_declaration(&self) -> bool
pub fn is_declaration(&self) -> bool
true for non-expression functions
Sourcepub fn has_use_strict_directive(&self) -> bool
pub fn has_use_strict_directive(&self) -> bool
Returns true if this function’s body has a "use strict" directive.