IdentifierReference

Struct IdentifierReference 

#[repr(C)]
pub struct IdentifierReference<'a> { pub span: Span, pub name: Atom<'a>, pub reference_id: Cell<Option<ReferenceId>>, }
x inside func in const x = 0; function func() { console.log(x); }

Represents an identifier reference, which is a reference to a variable, function, class, or object.

See: 13.1 Identifiers

Fields

span: Spanname: Atom<'a>

The name of the identifier being referenced.

reference_id: Cell<Option<ReferenceId>>

Reference ID

Identifies what identifier this refers to, and how it is used. This is set in the bind step of semantic analysis, and will always be None immediately after parsing.

Implementations

Source

impl IdentifierReference<'_>

pub fn reference_id(&self) -> ReferenceId

Get ReferenceId of IdentifierReference.

Only use this method on a post-semantic AST where ReferenceIds are always defined.

Panics

Panics if reference_id is None.

pub fn set_reference_id(&self, reference_id: ReferenceId)