JSXMemberExpression

Struct JSXMemberExpression 

#[repr(C)]
pub struct JSXMemberExpression<'a> { pub span: Span, pub object: JSXMemberExpressionObject<'a>, pub property: JSXIdentifier<'a>, }
JSX Member Expression

Used in JSXElementName. Multiple member expressions may be chained together. In this case, object will be a member expression.

Example

// <object.property />
<Apple.Orange />
<Foo.Bar.Baz.Bang />

Fields

span: Span

Node location in source code

object: JSXMemberExpressionObject<'a>

The object being accessed. This is everything before the last ..

property: JSXIdentifier<'a>

The property being accessed. This is everything after the last ..

Implementations

Source

impl<'a> JSXMemberExpression<'a>

pub fn get_identifier(&self) -> Option<&IdentifierReference<'a>>

Get the identifier being referenced, if there is one.

e.g. Foo in <Foo.bar> or <Foo.bar.qux>.

Returns None if the root of the JSXMemberExpression is this e.g. <this.bar> or <this.bar.qux>.