#[repr(C)]pub struct MethodDefinition<'a> {
pub span: Span,
pub decorators: Vec<'a, Decorator<'a>>,
pub key: PropertyKey<'a>,
pub value: Box<'a, Function<'a>>,
pub type: MethodDefinitionType,
pub kind: MethodDefinitionKind,
pub computed: bool,
pub static: bool,
pub override: bool,
pub optional: bool,
pub accessibility: Option<TSAccessibility>,
}Fields
span: Spandecorators: Vec<'a, Decorator<'a>>key: PropertyKey<'a>value: Box<'a, Function<'a>>type: MethodDefinitionTypeMethod definition type
This will always be true when an abstract modifier is used on the method.
kind: MethodDefinitionKindcomputed: boolstatic: booloverride: booloptional: boolaccessibility: Option<TSAccessibility>Trait Implementations
Sourceimpl<'new_alloc> CloneIn<'new_alloc> for MethodDefinition<'_>
impl<'new_alloc> CloneIn<'new_alloc> for MethodDefinition<'_>
Sourcetype Cloned = MethodDefinition<'new_alloc>
type Cloned = MethodDefinition<'new_alloc>
The type of the cloned object. Read more
Sourcefn clone_in(
&self,
allocator: &'new_alloc Allocator,
) -> <MethodDefinition<'_> as CloneIn<'new_alloc>>::Cloned
fn clone_in( &self, allocator: &'new_alloc Allocator, ) -> <MethodDefinition<'_> as CloneIn<'new_alloc>>::Cloned
Clone
self into the given allocator. allocator may be the same one
that self is already in.Sourcefn clone_in_with_semantic_ids(
&self,
allocator: &'new_alloc Allocator,
) -> <MethodDefinition<'_> as CloneIn<'new_alloc>>::Cloned
fn clone_in_with_semantic_ids( &self, allocator: &'new_alloc Allocator, ) -> <MethodDefinition<'_> as CloneIn<'new_alloc>>::Cloned
Almost identical as
clone_in, but for some special type, it will also clone the semantic ids.
Please use this method only if you make sure semantic info is synced with the ast node.Sourceimpl ContentEq for MethodDefinition<'_>
impl ContentEq for MethodDefinition<'_>
Sourcefn content_eq(&self, other: &MethodDefinition<'_>) -> bool
fn content_eq(&self, other: &MethodDefinition<'_>) -> bool
This method tests for contents of
self and other to be equal.Sourcefn content_ne(&self, other: &Self) -> bool
fn content_ne(&self, other: &Self) -> bool
This method tests for contents of
self and other not to be equal.
The default implementation is almost always
sufficient, and should not be overridden without very good reason.Sourceimpl<'a> Debug for MethodDefinition<'a>
impl<'a> Debug for MethodDefinition<'a>
Sourceimpl<'a> Dummy<'a> for MethodDefinition<'a>
impl<'a> Dummy<'a> for MethodDefinition<'a>
Sourcefn dummy(allocator: &'a Allocator) -> MethodDefinition<'a>
fn dummy(allocator: &'a Allocator) -> MethodDefinition<'a>
Create a dummy MethodDefinition.
Has cost of making 3 allocations (152 bytes).
Sourceimpl<'a> GatherNodeParts<'a> for MethodDefinition<'a>
impl<'a> GatherNodeParts<'a> for MethodDefinition<'a>
Sourceimpl Gen for MethodDefinition<'_>
impl Gen for MethodDefinition<'_>
Sourceimpl GetSpan for MethodDefinition<'_>
impl GetSpan for MethodDefinition<'_>
Sourceimpl GetSpanMut for MethodDefinition<'_>
impl GetSpanMut for MethodDefinition<'_>
Sourceimpl PrivateBoundIdentifiers for MethodDefinition<'_>
impl PrivateBoundIdentifiers for MethodDefinition<'_>
fn private_bound_identifiers(&self) -> Option<PrivateIdentifier<'_>>
Sourceimpl<'a> TakeIn<'a> for MethodDefinition<'a>
impl<'a> TakeIn<'a> for MethodDefinition<'a>
Sourcefn take_in<A>(&mut self, allocator_accessor: A) -> Selfwhere
A: AllocatorAccessor<'a>,
fn take_in<A>(&mut self, allocator_accessor: A) -> Selfwhere
A: AllocatorAccessor<'a>,
Replace node with a dummy.
Sourcefn take_in_box<A>(&mut self, allocator_accessor: A) -> Box<'a, Self>where
A: AllocatorAccessor<'a>,
fn take_in_box<A>(&mut self, allocator_accessor: A) -> Box<'a, Self>where
A: AllocatorAccessor<'a>,
Replace node with a boxed dummy.
Sourceimpl UnstableAddress for MethodDefinition<'_>
impl UnstableAddress for MethodDefinition<'_>