RegExpFlags

Struct RegExpFlags 

pub struct RegExpFlags(/* private fields */);
Implementations

Source

impl RegExpFlags

pub const G: RegExpFlags

Global flag

Causes the pattern to match multiple times.

pub const I: RegExpFlags

Ignore case flag

Causes the pattern to ignore case.

pub const M: RegExpFlags

Multiline flag

Causes ^ and $ to match the start/end of each line.

pub const S: RegExpFlags

DotAll flag

Causes . to also match newlines.

pub const U: RegExpFlags

Unicode flag

Causes the pattern to treat the input as a sequence of Unicode code points.

pub const Y: RegExpFlags

Sticky flag

Perform a “sticky” search that matches starting at the current position in the target string.

pub const D: RegExpFlags

Indices flag

Causes the regular expression to generate indices for substring matches.

pub const V: RegExpFlags

Unicode sets flag

Similar to the u flag, but also enables the \\p{} and \\P{} syntax. Added by the v flag proposal.

Source

impl RegExpFlags

pub const fn empty() -> RegExpFlags

Get a flags value with all bits unset.

pub const fn all() -> RegExpFlags

Get a flags value with all known bits set.

pub const fn bits(&self) -> u8

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u8) -> Option<RegExpFlags>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u8) -> RegExpFlags

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u8) -> RegExpFlags

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<RegExpFlags>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: RegExpFlags) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: RegExpFlags) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: RegExpFlags)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: RegExpFlags)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: RegExpFlags)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: RegExpFlags, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: RegExpFlags) -> RegExpFlags

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: RegExpFlags) -> RegExpFlags

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: RegExpFlags) -> RegExpFlags

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: RegExpFlags) -> RegExpFlags

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> RegExpFlags

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl RegExpFlags

pub const fn iter(&self) -> Iter<RegExpFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<RegExpFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl RegExpFlags

pub fn to_inline_string(self) -> InlineString<8, usize>

Convert RegExpFlags to an InlineString.

This performs the same role as RegExpFlags::to_string, but does not allocate.