pub struct SourceType { /* private fields */ }Expand description
Source Type for JavaScript vs TypeScript / Script vs Module / JSX
Implementations
Sourceimpl SourceType
impl SourceType
Sourcepub const fn cjs() -> SourceType
pub const fn cjs() -> SourceType
Creates a SourceType representing a regular JavaScript file.
This file could be a vanilla script (no module system of any kind) or a CommonJS file.
The resulting source type is not a module, nor does it support JSX.
Use SourceType::jsx for JSX sources.
Example
let js = SourceType::cjs();
assert!(js.is_javascript());
assert!(js.is_script()); // not a module
assert!(!js.is_jsx());Sourcepub const fn mjs() -> SourceType
pub const fn mjs() -> SourceType
Creates a SourceType representing a JavaScript file using ES6
modules. This is akin to a file with an .mjs extension.
Example
let mjs = SourceType::mjs();Sourcepub const fn unambiguous() -> SourceType
pub const fn unambiguous() -> SourceType
A SourceType that will be treated as a module if it contains ESM syntax.
After a file is parsed with an unambiguous source type, it will have a final
ModuleKind of either Module or Script.
Sourcepub const fn jsx() -> SourceType
pub const fn jsx() -> SourceType
Creates a SourceType representing a JavaScript` file with JSX.
Example
let jsx = SourceType::jsx();
assert!(jsx.is_javascript());
assert!(jsx.is_jsx());Sourcepub const fn ts() -> SourceType
pub const fn ts() -> SourceType
Creates a SourceType representing a TypeScript file.
Unlike SourceType::cjs, this method creates modules. Use
SourceType::tsx for TypeScript files with JSX support.
Example
let ts = SourceType::ts();
assert!(ts.is_typescript());
assert!(!ts.is_typescript_definition());
assert!(ts.is_module());
assert!(!ts.is_jsx());Sourcepub const fn tsx() -> SourceType
pub const fn tsx() -> SourceType
Creates a SourceType representing a TypeScript file with JSX.
Example
let tsx = SourceType::tsx();
assert!(tsx.is_typescript());
assert!(!tsx.is_typescript_definition());
assert!(tsx.is_module());
assert!(tsx.is_jsx());Sourcepub const fn d_ts() -> SourceType
pub const fn d_ts() -> SourceType
Creates a SourceType representing a [TypeScript definition] file.
Example
let dts = SourceType::d_ts();
assert!(dts.is_typescript());
assert!(dts.is_typescript_definition());
assert!(dts.is_module());
assert!(!dts.is_jsx());Sourcepub fn is_script(self) -> bool
pub fn is_script(self) -> bool
Returns true if this SourceType is script.
Sourcepub fn is_module(self) -> bool
pub fn is_module(self) -> bool
Returns true if this SourceType is module.
Sourcepub fn is_unambiguous(self) -> bool
pub fn is_unambiguous(self) -> bool
Returns true if this SourceType is unambiguous.
Sourcepub fn module_kind(self) -> ModuleKind
pub fn module_kind(self) -> ModuleKind
What module system is this source type using?
Sourcepub fn is_javascript(self) -> bool
pub fn is_javascript(self) -> bool
Returns true if this is a JavaScript file with or without syntax
extensions (like JSX).
Sourcepub fn is_typescript(self) -> bool
pub fn is_typescript(self) -> bool
Returns true if this is a TypeScript file or TypeScript definition file.
I.e., true for .ts, .cts, .mts, .tsx, and .d.ts files.
Sourcepub fn is_typescript_definition(self) -> bool
pub fn is_typescript_definition(self) -> bool
Returns true if this is a TypeScript definition file (e.g. .d.ts).
Sourcepub fn is_jsx(self) -> bool
pub fn is_jsx(self) -> bool
Returns true if this source type is using JSX.
Note that TSX is considered JSX in this context.
Sourcepub fn is_strict(self) -> bool
pub fn is_strict(self) -> bool
Does this source type implicitly use strict mode semantics?
Does not consider "use strict"; directives.
Sourcepub const fn with_script(self, yes: bool) -> SourceType
pub const fn with_script(self, yes: bool) -> SourceType
Mark this SourceType as a script if yes is true. No change
will occur if yes is false.
Sourcepub const fn with_module(self, yes: bool) -> SourceType
pub const fn with_module(self, yes: bool) -> SourceType
Mark this SourceType as a module if yes is true. No change
will occur if yes is false.
Sourcepub const fn with_unambiguous(self, yes: bool) -> SourceType
pub const fn with_unambiguous(self, yes: bool) -> SourceType
Mark this SourceType as unambiguous if yes is true. No change
will occur if yes is false.
Sourcepub const fn with_javascript(self, yes: bool) -> SourceType
pub const fn with_javascript(self, yes: bool) -> SourceType
Mark this SourceType as using JavaScript if yes is true. No change
will occur if yes is false.
Sourcepub const fn with_typescript(self, yes: bool) -> SourceType
pub const fn with_typescript(self, yes: bool) -> SourceType
Mark this SourceType as using TypeScript if yes is true. No change
will occur if yes is false.
Sourcepub const fn with_typescript_definition(self, yes: bool) -> SourceType
pub const fn with_typescript_definition(self, yes: bool) -> SourceType
Mark this SourceType as a [TypeScript definition] file if yes is true.
Sourcepub const fn with_jsx(self, yes: bool) -> SourceType
pub const fn with_jsx(self, yes: bool) -> SourceType
Mark this SourceType as using JSX if yes is true. No change
will occur if yes is false.
When using TypeScript, this source type now represents a TSX file.
Sourcepub const fn with_standard(self, yes: bool) -> SourceType
pub const fn with_standard(self, yes: bool) -> SourceType
Disable language extensions (e.g. JSX) if yes is true. No change
will occur if yes is false.
Sourcepub fn from_path<P>(path: P) -> Result<SourceType, UnknownExtension>
pub fn from_path<P>(path: P) -> Result<SourceType, UnknownExtension>
Converts a file Path to SourceType.
Examples
// supports .ts, .mts, .cts, .tsx, .d.ts, etc.
let ts = SourceType::from_path("foo.ts").unwrap();
assert!(ts.is_typescript());
assert!(!ts.is_typescript_definition());
// supports .js, .mjs, .cjs, .jsx
let jsx = SourceType::from_path("foo.jsx").unwrap();
assert!(jsx.is_javascript());
assert!(jsx.is_jsx());Behavior
JSX
All JavaScript-like files are treated as JSX, since some tools (like
babel) also do not make a distinction between .js and .jsx. However,
for TypeScript files, only .tsx files are treated as JSX.
Note that this behavior deviates from SourceType::cjs, which produces
scripts.
Modules vs. Scripts.
Oxc has partial support for Node’s
CommonJS detection
strategy. Any file with a .c[tj]s extension is treated as a script.
All other files are treated as modules.
Errors
Returns UnknownExtension if:
- there is no file name
- the file extension is not one of “js”, “mjs”, “cjs”, “jsx”, “ts”,
“mts”, “cts”, “tsx”. See
VALID_EXTENSIONSfor the list of valid extensions.
Sourcepub fn from_extension(extension: &str) -> Result<SourceType, UnknownExtension>
pub fn from_extension(extension: &str) -> Result<SourceType, UnknownExtension>
Converts a file extension to SourceType.
Errors
Returns UnknownExtension if:
- the file extension is not one of “js”, “mjs”, “cjs”, “jsx”, “ts”,
“mts”, “cts”, “tsx”. See
VALID_EXTENSIONSfor the list of valid extensions.