#[repr(C)]pub struct StringLiteral<'a> {
pub span: Span,
pub value: Atom<'a>,
pub raw: Option<Atom<'a>>,
pub lone_surrogates: bool,
}Expand description
String literal
Fields
span: SpanNode location in source code
value: Atom<'a>The value of the string.
Any escape sequences in the raw code are unescaped.
raw: Option<Atom<'a>>The raw string as it appears in source code.
None when this ast node is not constructed from the parser.
lone_surrogates: boolThe string value contains lone surrogates.
value is encoded using \u{FFFD} (the lossy replacement character) as an escape character.
Lone surrogates are encoded as \u{FFFD}XXXX, where XXXX is the code unit in hex.
The lossy escape character itself is encoded as \u{FFFD}fffd.
Implementations
Sourceimpl StringLiteral<'_>
impl StringLiteral<'_>
Sourcepub fn is_string_well_formed_unicode(&self) -> bool
pub fn is_string_well_formed_unicode(&self) -> bool
Static Semantics: IsStringWellFormedUnicode
test for \uD800-\uDFFF
See: https://tc39.es/ecma262/multipage/abstract-operations.html#sec-isstringwellformedunicode