SemanticBuilder

Struct SemanticBuilder 

pub struct SemanticBuilder<'a> { /* private fields */ }
Semantic analysis (scopes, symbols, references) Semantic Builder

Traverses a parsed AST and builds a Semantic representation of the program.

The main API is the build method.

Implementations

Source

impl<'a> SemanticBuilder<'a>

pub fn new() -> SemanticBuilder<'a>

pub fn with_check_syntax_error(self, yes: bool) -> SemanticBuilder<'a>

Enable/disable additional syntax checks.

Set this to true to enable additional syntax checks. Without these, there is no guarantee that the parsed program follows the ECMAScript spec.

By default, this is false.

pub fn with_cfg(self, _cfg: bool) -> SemanticBuilder<'a>

pub fn with_scope_tree_child_ids(self, yes: bool) -> SemanticBuilder<'a>

pub fn with_stats(self, stats: Stats) -> SemanticBuilder<'a>

Provide statistics about AST to optimize memory usage of semantic analysis.

Accurate statistics can greatly improve performance, especially for large ASTs. If no stats are provided, SemanticBuilder::build will compile stats by performing a complete AST traversal. If semantic analysis has already been performed on this AST, get the existing stats with Semantic::stats, and pass them in with this method, to avoid the stats collection AST pass.

pub fn with_excess_capacity(self, excess_capacity: f64) -> SemanticBuilder<'a>

Request SemanticBuilder to allocate excess capacity for scopes, symbols, and references.

excess_capacity is provided as a fraction. e.g. to over-allocate by 20%, pass 0.2 as excess_capacity.

Has no effect if a Stats object is provided with SemanticBuilder::with_stats, only if SemanticBuilder is calculating stats itself.

This is useful when you intend to modify Semantic, adding more nodes, scopes, symbols, or references. Allocating excess capacity for these additions at the outset prevents Semantic’s data structures needing to grow later on which involves memory copying. For large ASTs with a lot of semantic data, re-allocation can be very costly.

pub fn build(self, program: &'a Program<'a>) -> SemanticBuilderReturn<'a>

Finalize the builder.

Panics