pub struct SymbolFlags(/* private fields */);Expand description
Semantic analysis (scopes, symbols, references)
Implementations
Sourceimpl SymbolFlags
impl SymbolFlags
pub const None: SymbolFlags
Sourcepub const FunctionScopedVariable: SymbolFlags
pub const FunctionScopedVariable: SymbolFlags
Variable (var) or parameter
Sourcepub const BlockScopedVariable: SymbolFlags
pub const BlockScopedVariable: SymbolFlags
A block-scoped variable (let or const)
Sourcepub const ConstVariable: SymbolFlags
pub const ConstVariable: SymbolFlags
A const variable (const)
pub const Class: SymbolFlags
Sourcepub const CatchVariable: SymbolFlags
pub const CatchVariable: SymbolFlags
try {} catch(catch_variable) {}
Sourcepub const Function: SymbolFlags
pub const Function: SymbolFlags
A function declaration or expression
Sourcepub const Import: SymbolFlags
pub const Import: SymbolFlags
Imported ESM binding
Sourcepub const TypeImport: SymbolFlags
pub const TypeImport: SymbolFlags
Imported ESM type-only binding
pub const TypeAlias: SymbolFlags
pub const Interface: SymbolFlags
pub const RegularEnum: SymbolFlags
pub const ConstEnum: SymbolFlags
pub const EnumMember: SymbolFlags
pub const TypeParameter: SymbolFlags
Sourcepub const NamespaceModule: SymbolFlags
pub const NamespaceModule: SymbolFlags
Uninstantiated module
Sourcepub const ValueModule: SymbolFlags
pub const ValueModule: SymbolFlags
Instantiated module
Sourcepub const Ambient: SymbolFlags
pub const Ambient: SymbolFlags
Declared with declare modifier, like declare function x() {}.
pub const Enum: SymbolFlags
pub const Variable: SymbolFlags
pub const BlockScoped: SymbolFlags
pub const Value: SymbolFlags
pub const Type: SymbolFlags
pub const Namespace: SymbolFlags
Sourcepub const FunctionScopedVariableExcludes: SymbolFlags
pub const FunctionScopedVariableExcludes: SymbolFlags
Variables can be redeclared, but can not redeclare a block-scoped declaration with the same name, or any other value that is not a variable, e.g. ValueModule or Class
Sourcepub const BlockScopedVariableExcludes: SymbolFlags
pub const BlockScopedVariableExcludes: SymbolFlags
Block-scoped declarations are not allowed to be re-declared they can not merge with anything in the value space
pub const FunctionExcludes: SymbolFlags
pub const ClassExcludes: SymbolFlags
pub const ImportBindingExcludes: SymbolFlags
pub const TypeAliasExcludes: SymbolFlags
pub const InterfaceExcludes: SymbolFlags
pub const TypeParameterExcludes: SymbolFlags
pub const ConstEnumExcludes: SymbolFlags
pub const ValueModuleExcludes: SymbolFlags
pub const NamespaceModuleExcludes: SymbolFlags
pub const RegularEnumExcludes: SymbolFlags
pub const EnumMemberExcludes: SymbolFlags
Sourceimpl SymbolFlags
impl SymbolFlags
Sourcepub const fn empty() -> SymbolFlags
pub const fn empty() -> SymbolFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> SymbolFlags
pub const fn all() -> SymbolFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<SymbolFlags>
pub const fn from_bits(bits: u32) -> Option<SymbolFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> SymbolFlags
pub const fn from_bits_truncate(bits: u32) -> SymbolFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> SymbolFlags
pub const fn from_bits_retain(bits: u32) -> SymbolFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SymbolFlags>
pub fn from_name(name: &str) -> Option<SymbolFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SymbolFlags) -> bool
pub const fn intersects(&self, other: SymbolFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: SymbolFlags) -> bool
pub const fn contains(&self, other: SymbolFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: SymbolFlags)
pub fn insert(&mut self, other: SymbolFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: SymbolFlags)
pub fn remove(&mut self, other: SymbolFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SymbolFlags)
pub fn toggle(&mut self, other: SymbolFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: SymbolFlags, value: bool)
pub fn set(&mut self, other: SymbolFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SymbolFlags) -> SymbolFlags
pub const fn intersection(self, other: SymbolFlags) -> SymbolFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: SymbolFlags) -> SymbolFlags
pub const fn union(self, other: SymbolFlags) -> SymbolFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: SymbolFlags) -> SymbolFlags
pub const fn difference(self, other: SymbolFlags) -> SymbolFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SymbolFlags) -> SymbolFlags
pub const fn symmetric_difference(self, other: SymbolFlags) -> SymbolFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> SymbolFlags
pub const fn complement(self) -> SymbolFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SymbolFlags
impl SymbolFlags
Sourcepub const fn iter(&self) -> Iter<SymbolFlags>
pub const fn iter(&self) -> Iter<SymbolFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SymbolFlags>
pub const fn iter_names(&self) -> IterNames<SymbolFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl SymbolFlags
impl SymbolFlags
pub fn is_variable(self) -> bool
pub fn is_type_parameter(self) -> bool
Sourcepub fn is_type(self) -> bool
pub fn is_type(self) -> bool
If true, then the symbol is a type, such as a TypeAlias, Interface, or Enum
Sourcepub fn is_value(self) -> bool
pub fn is_value(self) -> bool
If true, then the symbol is a value, such as a Variable, Function, or Class
pub fn is_const_variable(self) -> bool
Sourcepub fn is_function(self) -> bool
pub fn is_function(self) -> bool
Returns true if this symbol is a function declaration or expression.
pub fn is_class(self) -> bool
pub fn is_interface(self) -> bool
pub fn is_type_alias(self) -> bool
pub fn is_enum(self) -> bool
pub fn is_const_enum(self) -> bool
pub fn is_enum_member(self) -> bool
pub fn is_catch_variable(self) -> bool
pub fn is_function_scoped_declaration(self) -> bool
pub fn is_import(self) -> bool
pub fn is_type_import(self) -> bool
pub fn is_ambient(self) -> bool
pub fn is_namespace_module(self) -> bool
pub fn is_value_module(self) -> bool
Sourcepub fn can_be_referenced_by_type(self) -> bool
pub fn can_be_referenced_by_type(self) -> bool
If true, then the symbol can be referenced by a type reference
Sourcepub fn can_be_referenced_by_value(self) -> bool
pub fn can_be_referenced_by_value(self) -> bool
If true, then the symbol can be referenced by a value reference
Sourcepub fn can_be_referenced_by_value_as_type(self) -> bool
pub fn can_be_referenced_by_value_as_type(self) -> bool
If true, then the symbol can be referenced by a value_as_type reference