pub struct TransformOptions {
pub cwd: PathBuf,
pub assumptions: CompilerAssumptions,
pub typescript: TypeScriptOptions,
pub decorator: DecoratorOptions,
pub jsx: JsxOptions,
pub env: EnvOptions,
pub proposals: ProposalOptions,
pub plugins: PluginsOptions,
pub helper_loader: HelperLoaderOptions,
}Expand description
AST transformer (JSX, TypeScript, etc.) https://babel.dev/docs/options
Fields
cwd: PathBufThe working directory that all paths in the programmatic options will be resolved relative to.
assumptions: CompilerAssumptionsSet assumptions in order to produce smaller output. For more information, check the assumptions documentation page.
typescript: TypeScriptOptionsdecorator: DecoratorOptionsDecorator
jsx: JsxOptionsJsx Transform
See preset-react
env: EnvOptionsECMAScript Env Options
proposals: ProposalOptionsProposals
plugins: PluginsOptionsPlugins
helper_loader: HelperLoaderOptionsImplementations
Sourceimpl TransformOptions
impl TransformOptions
Sourcepub fn from_target(s: &str) -> Result<TransformOptions, String>
pub fn from_target(s: &str) -> Result<TransformOptions, String>
Initialize from a comma separated list of targets and environmenss.
e.g. es2022,chrome58,edge16.
Errors
- Same targets specified multiple times.
- No matching target.
- Invalid version.
Sourcepub fn from_target_list<S>(list: &[S]) -> Result<TransformOptions, String>
pub fn from_target_list<S>(list: &[S]) -> Result<TransformOptions, String>
Initialize from a list of targets and environmenss.
e.g. ["es2020", "chrome58", "edge16", "firefox57", "node12", "safari11"].
target: es5, es2015 … es2024, esnext.
environment: chrome, deno, edge, firefox, hermes, ie, ios, node, opera, rhino, safari
https://esbuild.github.io/api/#target
Errors
- Same targets specified multiple times.
- No matching target.
- Invalid version.