pub struct SymbolTable {
pub symbols: Vec<Symbol>,
pub scope_count: usize,
}Expand description
Collection of all symbols in a module.
This is the primary output of semantic analysis for a single file.
Fields
symbols: Vec<Symbol>All declared symbols in the module
scope_count: usizeNumber of scopes in the module (from Oxc)
Implementations
Sourceimpl SymbolTable
impl SymbolTable
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Create a symbol table with a known capacity.
Sourcepub fn add_symbol(&mut self, symbol: Symbol)
pub fn add_symbol(&mut self, symbol: Symbol)
Add a symbol to the table.
Sourcepub fn unused_symbols(&self) -> Vec<&Symbol>
pub fn unused_symbols(&self) -> Vec<&Symbol>
Get all unused symbols in this table.
Sourcepub fn symbols_by_name(&self, name: &str) -> Vec<&Symbol>
pub fn symbols_by_name(&self, name: &str) -> Vec<&Symbol>
Get symbols by name.
Sourcepub fn mark_exports(&mut self, export_names: &[String])
pub fn mark_exports(&mut self, export_names: &[String])
Mark symbols as exported if their names appear in the export list.
Sourcepub fn enum_members_by_enum(&self) -> HashMap<String, Vec<&Symbol>>
pub fn enum_members_by_enum(&self) -> HashMap<String, Vec<&Symbol>>
Get all enum members grouped by enum name
Sourcepub fn unused_enum_members(&self) -> Vec<&Symbol>
pub fn unused_enum_members(&self) -> Vec<&Symbol>
Get unused enum members