Graph walker for dependency traversal.
Performs BFS traversal of the import graph, parsing modules and building a CollectionState that can be converted to a ModuleGraph.
Structs
- Graph
Walker - Graph walker that traverses the dependency graph.
- Path
Traversal Error - Error indicating a path traversal attempt was detected.
Enums
- Walker
Error - Error that can occur during graph walking.
Functions
- normalize_
and_ validate_ path - Normalize a path and validate it stays within the cwd.
- validate_
path_ within_ cwd - Validate that a normalized path stays within the current working directory.