#[repr(C, u8)]pub enum Expression<'a> {
Show 43 variants
BooleanLiteral(Box<'a, BooleanLiteral>),
NullLiteral(Box<'a, NullLiteral>),
NumericLiteral(Box<'a, NumericLiteral<'a>>),
BigIntLiteral(Box<'a, BigIntLiteral<'a>>),
RegExpLiteral(Box<'a, RegExpLiteral<'a>>),
StringLiteral(Box<'a, StringLiteral<'a>>),
TemplateLiteral(Box<'a, TemplateLiteral<'a>>),
Identifier(Box<'a, IdentifierReference<'a>>),
MetaProperty(Box<'a, MetaProperty<'a>>),
Super(Box<'a, Super>),
ArrayExpression(Box<'a, ArrayExpression<'a>>),
ArrowFunctionExpression(Box<'a, ArrowFunctionExpression<'a>>),
AssignmentExpression(Box<'a, AssignmentExpression<'a>>),
AwaitExpression(Box<'a, AwaitExpression<'a>>),
BinaryExpression(Box<'a, BinaryExpression<'a>>),
CallExpression(Box<'a, CallExpression<'a>>),
ChainExpression(Box<'a, ChainExpression<'a>>),
ClassExpression(Box<'a, Class<'a>>),
ConditionalExpression(Box<'a, ConditionalExpression<'a>>),
FunctionExpression(Box<'a, Function<'a>>),
ImportExpression(Box<'a, ImportExpression<'a>>),
LogicalExpression(Box<'a, LogicalExpression<'a>>),
NewExpression(Box<'a, NewExpression<'a>>),
ObjectExpression(Box<'a, ObjectExpression<'a>>),
ParenthesizedExpression(Box<'a, ParenthesizedExpression<'a>>),
SequenceExpression(Box<'a, SequenceExpression<'a>>),
TaggedTemplateExpression(Box<'a, TaggedTemplateExpression<'a>>),
ThisExpression(Box<'a, ThisExpression>),
UnaryExpression(Box<'a, UnaryExpression<'a>>),
UpdateExpression(Box<'a, UpdateExpression<'a>>),
YieldExpression(Box<'a, YieldExpression<'a>>),
PrivateInExpression(Box<'a, PrivateInExpression<'a>>),
JSXElement(Box<'a, JSXElement<'a>>),
JSXFragment(Box<'a, JSXFragment<'a>>),
TSAsExpression(Box<'a, TSAsExpression<'a>>),
TSSatisfiesExpression(Box<'a, TSSatisfiesExpression<'a>>),
TSTypeAssertion(Box<'a, TSTypeAssertion<'a>>),
TSNonNullExpression(Box<'a, TSNonNullExpression<'a>>),
TSInstantiationExpression(Box<'a, TSInstantiationExpression<'a>>),
V8IntrinsicExpression(Box<'a, V8IntrinsicExpression<'a>>),
ComputedMemberExpression(Box<'a, ComputedMemberExpression<'a>>),
StaticMemberExpression(Box<'a, StaticMemberExpression<'a>>),
PrivateFieldExpression(Box<'a, PrivateFieldExpression<'a>>),
}Expand description
Represents a type for AST nodes corresponding to JavaScript’s expressions.
Inherits variants from MemberExpression. See ast module docs for explanation of inheritance.
Variants
BooleanLiteral(Box<'a, BooleanLiteral>)
See BooleanLiteral for AST node details.
NullLiteral(Box<'a, NullLiteral>)
See NullLiteral for AST node details.
NumericLiteral(Box<'a, NumericLiteral<'a>>)
See NumericLiteral for AST node details.
BigIntLiteral(Box<'a, BigIntLiteral<'a>>)
See BigIntLiteral for AST node details.
RegExpLiteral(Box<'a, RegExpLiteral<'a>>)
See RegExpLiteral for AST node details.
StringLiteral(Box<'a, StringLiteral<'a>>)
See StringLiteral for AST node details.
TemplateLiteral(Box<'a, TemplateLiteral<'a>>)
See TemplateLiteral for AST node details.
Identifier(Box<'a, IdentifierReference<'a>>)
See IdentifierReference for AST node details.
MetaProperty(Box<'a, MetaProperty<'a>>)
See MetaProperty for AST node details.
Super(Box<'a, Super>)
See Super for AST node details.
ArrayExpression(Box<'a, ArrayExpression<'a>>)
See ArrayExpression for AST node details.
ArrowFunctionExpression(Box<'a, ArrowFunctionExpression<'a>>)
See ArrowFunctionExpression for AST node details.
AssignmentExpression(Box<'a, AssignmentExpression<'a>>)
See AssignmentExpression for AST node details.
AwaitExpression(Box<'a, AwaitExpression<'a>>)
See AwaitExpression for AST node details.
BinaryExpression(Box<'a, BinaryExpression<'a>>)
See BinaryExpression for AST node details.
CallExpression(Box<'a, CallExpression<'a>>)
See CallExpression for AST node details.
ChainExpression(Box<'a, ChainExpression<'a>>)
See ChainExpression for AST node details.
ClassExpression(Box<'a, Class<'a>>)
See Class for AST node details.
ConditionalExpression(Box<'a, ConditionalExpression<'a>>)
See ConditionalExpression for AST node details.
FunctionExpression(Box<'a, Function<'a>>)
See Function for AST node details.
ImportExpression(Box<'a, ImportExpression<'a>>)
See ImportExpression for AST node details.
LogicalExpression(Box<'a, LogicalExpression<'a>>)
See LogicalExpression for AST node details.
NewExpression(Box<'a, NewExpression<'a>>)
See NewExpression for AST node details.
ObjectExpression(Box<'a, ObjectExpression<'a>>)
See ObjectExpression for AST node details.
ParenthesizedExpression(Box<'a, ParenthesizedExpression<'a>>)
See ParenthesizedExpression for AST node details.
SequenceExpression(Box<'a, SequenceExpression<'a>>)
See SequenceExpression for AST node details.
TaggedTemplateExpression(Box<'a, TaggedTemplateExpression<'a>>)
See TaggedTemplateExpression for AST node details.
ThisExpression(Box<'a, ThisExpression>)
See ThisExpression for AST node details.
UnaryExpression(Box<'a, UnaryExpression<'a>>)
See UnaryExpression for AST node details.
UpdateExpression(Box<'a, UpdateExpression<'a>>)
See UpdateExpression for AST node details.
YieldExpression(Box<'a, YieldExpression<'a>>)
See YieldExpression for AST node details.
PrivateInExpression(Box<'a, PrivateInExpression<'a>>)
See PrivateInExpression for AST node details.
JSXElement(Box<'a, JSXElement<'a>>)
See JSXElement for AST node details.
JSXFragment(Box<'a, JSXFragment<'a>>)
See JSXFragment for AST node details.
TSAsExpression(Box<'a, TSAsExpression<'a>>)
See TSAsExpression for AST node details.
TSSatisfiesExpression(Box<'a, TSSatisfiesExpression<'a>>)
See TSSatisfiesExpression for AST node details.
TSTypeAssertion(Box<'a, TSTypeAssertion<'a>>)
See TSTypeAssertion for AST node details.
TSNonNullExpression(Box<'a, TSNonNullExpression<'a>>)
See TSNonNullExpression for AST node details.
TSInstantiationExpression(Box<'a, TSInstantiationExpression<'a>>)
See TSInstantiationExpression for AST node details.
V8IntrinsicExpression(Box<'a, V8IntrinsicExpression<'a>>)
See V8IntrinsicExpression for AST node details.
ComputedMemberExpression(Box<'a, ComputedMemberExpression<'a>>)
Inherited from MemberExpression.
MemberExpression[?Yield, ?Await] [ Expression[+In, ?Yield, ?Await] ]
StaticMemberExpression(Box<'a, StaticMemberExpression<'a>>)
Inherited from MemberExpression.
MemberExpression[?Yield, ?Await] . IdentifierName
PrivateFieldExpression(Box<'a, PrivateFieldExpression<'a>>)
Inherited from MemberExpression.
MemberExpression[?Yield, ?Await] . PrivateIdentifier
Implementations
Sourceimpl<'a> Expression<'a>
impl<'a> Expression<'a>
Sourcepub fn is_member_expression(&self) -> bool
pub fn is_member_expression(&self) -> bool
Return if a Expression is a MemberExpression.
Sourcepub fn into_member_expression(self) -> MemberExpression<'a>
pub fn into_member_expression(self) -> MemberExpression<'a>
Sourcepub fn as_member_expression(&self) -> Option<&MemberExpression<'a>>
pub fn as_member_expression(&self) -> Option<&MemberExpression<'a>>
Convert &Expression to &MemberExpression.
Sourcepub fn as_member_expression_mut(&mut self) -> Option<&mut MemberExpression<'a>>
pub fn as_member_expression_mut(&mut self) -> Option<&mut MemberExpression<'a>>
Convert &mut Expression to &mut MemberExpression.
Sourcepub fn to_member_expression(&self) -> &MemberExpression<'a>
pub fn to_member_expression(&self) -> &MemberExpression<'a>
Sourcepub fn to_member_expression_mut(&mut self) -> &mut MemberExpression<'a>
pub fn to_member_expression_mut(&mut self) -> &mut MemberExpression<'a>
Sourceimpl<'a> Expression<'a>
impl<'a> Expression<'a>
Sourcepub fn is_typescript_syntax(&self) -> bool
pub fn is_typescript_syntax(&self) -> bool
Returns true if this expression is TypeScript-specific syntax.
Sourcepub fn is_primary_expression(&self) -> bool
pub fn is_primary_expression(&self) -> bool
Returns true if this is a primary expression.
Sourcepub fn is_literal(&self) -> bool
pub fn is_literal(&self) -> bool
true if this Expression is a literal expression for a primitive value.
Does not include TemplateLiterals, object literals, or array literals.
Sourcepub fn is_string_literal(&self) -> bool
pub fn is_string_literal(&self) -> bool
Sourcepub fn is_no_substitution_template(&self) -> bool
pub fn is_no_substitution_template(&self) -> bool
Return true if the expression is a plain template.
Sourcepub fn is_number_literal(&self) -> bool
pub fn is_number_literal(&self) -> bool
Sourcepub fn is_big_int_literal(&self) -> bool
pub fn is_big_int_literal(&self) -> bool
Returns true for bigint literals.
Sourcepub fn is_specific_string_literal(&self, string: &str) -> bool
pub fn is_specific_string_literal(&self, string: &str) -> bool
Returns true for string literals matching the
expected value. Note that non-substitution template
literals are not considered.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Determines whether the given expr is a undefined literal
Sourcepub fn is_number(&self) -> bool
pub fn is_number(&self) -> bool
Returns true for numeric literals
Sourcepub fn is_number_0(&self) -> bool
pub fn is_number_0(&self) -> bool
Determines whether the given expr is a 0
Sourcepub fn is_number_value(&self, val: f64) -> bool
pub fn is_number_value(&self, val: f64) -> bool
Determines whether the given expr is a specific number literal.
Sourcepub fn is_specific_raw_number_literal(&self, val: &str) -> bool
pub fn is_specific_raw_number_literal(&self, val: &str) -> bool
Determines whether the given numeral literal’s raw value is exactly val
Sourcepub fn evaluate_to_undefined(&self) -> bool
pub fn evaluate_to_undefined(&self) -> bool
Determines whether the given expr evaluate to undefined
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Determines whether the given expr is a null or undefined or void 0
Corresponds to a nullish value check.
Sourcepub fn without_parentheses(&self) -> &Expression<'a>
pub fn without_parentheses(&self) -> &Expression<'a>
Remove nested parentheses from this expression.
Sourcepub fn without_parentheses_mut(&mut self) -> &mut Expression<'a>
pub fn without_parentheses_mut(&mut self) -> &mut Expression<'a>
Remove nested parentheses from this expression.
Sourcepub fn is_specific_id(&self, name: &str) -> bool
pub fn is_specific_id(&self, name: &str) -> bool
Returns true if this Expression is an IdentifierReference with specified name.
Sourcepub fn is_specific_member_access(&self, object: &str, property: &str) -> bool
pub fn is_specific_member_access(&self, object: &str, property: &str) -> bool
Returns true if this Expression is a MemberExpression with the specified object
name and property name.
For example, Array.from is a specific member access with object Array and property from
and could be checked like expr.is_specific_member_access("Array", "from").
Sourcepub fn into_inner_expression(self) -> Expression<'a>
pub fn into_inner_expression(self) -> Expression<'a>
Returns the expression inside of this one, if applicable, and takes ownership of it.
For example, if the expression is a ParenthesizedExpression, it will return the
expression inside the parentheses. Or if this is part of a TypeScript expression
like as, satisfies, or !, then it will return the expression that is being type asserted.
For getting a reference to the expression inside, use Expression::get_inner_expression.
Sourcepub fn get_inner_expression(&self) -> &Expression<'a>
pub fn get_inner_expression(&self) -> &Expression<'a>
Gets the expression inside of this one, if applicable, and returns a reference to it.
For example, if the expression is a ParenthesizedExpression, it will return the
expression inside the parentheses. Or if this is part of a TypeScript expression
like as, satisfies, or !, then it will return the expression that is being type asserted.
For taking ownership of the expression inside, use Expression::into_inner_expression.
For getting a mutable reference to the expression inside, use Expression::get_inner_expression_mut.
Sourcepub fn get_inner_expression_mut(&mut self) -> &mut Expression<'a>
pub fn get_inner_expression_mut(&mut self) -> &mut Expression<'a>
Gets the expression inside of this one, if applicable, and returns a mutable reference to it.
For example, if the expression is a ParenthesizedExpression, it will return the
expression inside the parentheses. Or if this is part of a TypeScript expression
like as, satisfies, or !, then it will return the expression that is being type asserted.
For taking ownership of the expression inside, use Expression::into_inner_expression.
For getting an immutable reference to the expression inside, use Expression::get_inner_expression.
Sourcepub fn into_chain_element(self) -> Option<ChainElement<'a>>
pub fn into_chain_element(self) -> Option<ChainElement<'a>>
Turns any chainable expression such as a.b or b() into the chained equivalent
such as a?.b or b?.().
Sourcepub fn is_identifier_reference(&self) -> bool
pub fn is_identifier_reference(&self) -> bool
Returns true if this Expression is an IdentifierReference.
Sourcepub fn get_identifier_reference(&self) -> Option<&IdentifierReference<'a>>
pub fn get_identifier_reference(&self) -> Option<&IdentifierReference<'a>>
Returns the IdentifierReference if this expression is an Expression::Identifier,
or contains an Expression::Identifier and reruns None otherwise.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Returns true if this Expression is a function
(either Function or ArrowFunctionExpression).
Sourcepub fn is_anonymous_function_definition(&self) -> bool
pub fn is_anonymous_function_definition(&self) -> bool
Returns true if this Expression is an anonymous function definition.
Note that this includes Classs.
https://262.ecma-international.org/15.0/#sec-isanonymousfunctiondefinition
Sourcepub fn is_call_expression(&self) -> bool
pub fn is_call_expression(&self) -> bool
Returns true if this Expression is a CallExpression.
Sourcepub fn is_super(&self) -> bool
pub fn is_super(&self) -> bool
Returns true if this Expression is a Super.
Sourcepub fn is_super_call_expression(&self) -> bool
pub fn is_super_call_expression(&self) -> bool
Returns true if this Expression is a CallExpression with Super as callee.
Sourcepub fn is_call_like_expression(&self) -> bool
pub fn is_call_like_expression(&self) -> bool
Returns true if this Expression is a CallExpression, NewExpression,
or ImportExpression.
Sourcepub fn is_binaryish(&self) -> bool
pub fn is_binaryish(&self) -> bool
Returns true if this Expression is a BinaryExpression or LogicalExpression.
Sourcepub fn get_member_expr(&self) -> Option<&MemberExpression<'a>>
pub fn get_member_expr(&self) -> Option<&MemberExpression<'a>>
Returns the MemberExpression if this expression is a MemberExpression, contains a
MemberExpression, or is or part of a ChainExpression (such as a?.b),
and returns None otherwise if this is not a member expression.
Sourcepub fn is_require_call(&self) -> bool
pub fn is_require_call(&self) -> bool
Returns true if this Expression is a require call.
See CallExpression::is_require_call for details of the exact patterns that match.
Sourcepub fn is_assignment(&self) -> bool
pub fn is_assignment(&self) -> bool
Returns true if this is an assignment expression.
Sourcepub fn is_entity_name_expression(&self) -> bool
pub fn is_entity_name_expression(&self) -> bool
Is identifier or a.b expression where a is an identifier.
Sourcepub fn is_property_access_entity_name_expression(&self) -> bool
pub fn is_property_access_entity_name_expression(&self) -> bool
a.b expression where a is an identifier.
Sourcepub fn is_jsx(&self) -> bool
pub fn is_jsx(&self) -> bool
Returns true if this Expression is a JSXElement or JSXFragment.