#[repr(C, u8)]pub enum PropertyKey<'a> {
Show 45 variants
StaticIdentifier(Box<'a, IdentifierName<'a>>),
PrivateIdentifier(Box<'a, PrivateIdentifier<'a>>),
BooleanLiteral(Box<'a, BooleanLiteral>),
NullLiteral(Box<'a, NullLiteral>),
NumericLiteral(Box<'a, NumericLiteral<'a>>),
BigIntLiteral(Box<'a, BigIntLiteral<'a>>),
RegExpLiteral(Box<'a, RegExpLiteral<'a>>),
StringLiteral(Box<'a, StringLiteral<'a>>),
TemplateLiteral(Box<'a, TemplateLiteral<'a>>),
Identifier(Box<'a, IdentifierReference<'a>>),
MetaProperty(Box<'a, MetaProperty<'a>>),
Super(Box<'a, Super>),
ArrayExpression(Box<'a, ArrayExpression<'a>>),
ArrowFunctionExpression(Box<'a, ArrowFunctionExpression<'a>>),
AssignmentExpression(Box<'a, AssignmentExpression<'a>>),
AwaitExpression(Box<'a, AwaitExpression<'a>>),
BinaryExpression(Box<'a, BinaryExpression<'a>>),
CallExpression(Box<'a, CallExpression<'a>>),
ChainExpression(Box<'a, ChainExpression<'a>>),
ClassExpression(Box<'a, Class<'a>>),
ConditionalExpression(Box<'a, ConditionalExpression<'a>>),
FunctionExpression(Box<'a, Function<'a>>),
ImportExpression(Box<'a, ImportExpression<'a>>),
LogicalExpression(Box<'a, LogicalExpression<'a>>),
NewExpression(Box<'a, NewExpression<'a>>),
ObjectExpression(Box<'a, ObjectExpression<'a>>),
ParenthesizedExpression(Box<'a, ParenthesizedExpression<'a>>),
SequenceExpression(Box<'a, SequenceExpression<'a>>),
TaggedTemplateExpression(Box<'a, TaggedTemplateExpression<'a>>),
ThisExpression(Box<'a, ThisExpression>),
UnaryExpression(Box<'a, UnaryExpression<'a>>),
UpdateExpression(Box<'a, UpdateExpression<'a>>),
YieldExpression(Box<'a, YieldExpression<'a>>),
PrivateInExpression(Box<'a, PrivateInExpression<'a>>),
JSXElement(Box<'a, JSXElement<'a>>),
JSXFragment(Box<'a, JSXFragment<'a>>),
TSAsExpression(Box<'a, TSAsExpression<'a>>),
TSSatisfiesExpression(Box<'a, TSSatisfiesExpression<'a>>),
TSTypeAssertion(Box<'a, TSTypeAssertion<'a>>),
TSNonNullExpression(Box<'a, TSNonNullExpression<'a>>),
TSInstantiationExpression(Box<'a, TSInstantiationExpression<'a>>),
V8IntrinsicExpression(Box<'a, V8IntrinsicExpression<'a>>),
ComputedMemberExpression(Box<'a, ComputedMemberExpression<'a>>),
StaticMemberExpression(Box<'a, StaticMemberExpression<'a>>),
PrivateFieldExpression(Box<'a, PrivateFieldExpression<'a>>),
}Expand description
Property Key
Inherits variants from Expression. See ast module docs for explanation of inheritance.
Variants
StaticIdentifier(Box<'a, IdentifierName<'a>>)
a in const obj = { a: 1 }; obj.a;
PrivateIdentifier(Box<'a, PrivateIdentifier<'a>>)
#a in class C { #a = 1; }; const c = new C(); c.#a;
BooleanLiteral(Box<'a, BooleanLiteral>)
Inherited from Expression
NullLiteral(Box<'a, NullLiteral>)
Inherited from Expression
NumericLiteral(Box<'a, NumericLiteral<'a>>)
Inherited from Expression
BigIntLiteral(Box<'a, BigIntLiteral<'a>>)
Inherited from Expression
RegExpLiteral(Box<'a, RegExpLiteral<'a>>)
Inherited from Expression
StringLiteral(Box<'a, StringLiteral<'a>>)
Inherited from Expression
TemplateLiteral(Box<'a, TemplateLiteral<'a>>)
Inherited from Expression
Identifier(Box<'a, IdentifierReference<'a>>)
Inherited from Expression
MetaProperty(Box<'a, MetaProperty<'a>>)
Inherited from Expression
Super(Box<'a, Super>)
Inherited from Expression
ArrayExpression(Box<'a, ArrayExpression<'a>>)
Inherited from Expression
ArrowFunctionExpression(Box<'a, ArrowFunctionExpression<'a>>)
Inherited from Expression
AssignmentExpression(Box<'a, AssignmentExpression<'a>>)
Inherited from Expression
AwaitExpression(Box<'a, AwaitExpression<'a>>)
Inherited from Expression
BinaryExpression(Box<'a, BinaryExpression<'a>>)
Inherited from Expression
CallExpression(Box<'a, CallExpression<'a>>)
Inherited from Expression
ChainExpression(Box<'a, ChainExpression<'a>>)
Inherited from Expression
ClassExpression(Box<'a, Class<'a>>)
Inherited from Expression
ConditionalExpression(Box<'a, ConditionalExpression<'a>>)
Inherited from Expression
FunctionExpression(Box<'a, Function<'a>>)
Inherited from Expression
ImportExpression(Box<'a, ImportExpression<'a>>)
Inherited from Expression
LogicalExpression(Box<'a, LogicalExpression<'a>>)
Inherited from Expression
NewExpression(Box<'a, NewExpression<'a>>)
Inherited from Expression
ObjectExpression(Box<'a, ObjectExpression<'a>>)
Inherited from Expression
ParenthesizedExpression(Box<'a, ParenthesizedExpression<'a>>)
Inherited from Expression
SequenceExpression(Box<'a, SequenceExpression<'a>>)
Inherited from Expression
TaggedTemplateExpression(Box<'a, TaggedTemplateExpression<'a>>)
Inherited from Expression
ThisExpression(Box<'a, ThisExpression>)
Inherited from Expression
UnaryExpression(Box<'a, UnaryExpression<'a>>)
Inherited from Expression
UpdateExpression(Box<'a, UpdateExpression<'a>>)
Inherited from Expression
YieldExpression(Box<'a, YieldExpression<'a>>)
Inherited from Expression
PrivateInExpression(Box<'a, PrivateInExpression<'a>>)
Inherited from Expression
JSXElement(Box<'a, JSXElement<'a>>)
Inherited from Expression
JSXFragment(Box<'a, JSXFragment<'a>>)
Inherited from Expression
TSAsExpression(Box<'a, TSAsExpression<'a>>)
Inherited from Expression
TSSatisfiesExpression(Box<'a, TSSatisfiesExpression<'a>>)
Inherited from Expression
TSTypeAssertion(Box<'a, TSTypeAssertion<'a>>)
Inherited from Expression
TSNonNullExpression(Box<'a, TSNonNullExpression<'a>>)
Inherited from Expression
TSInstantiationExpression(Box<'a, TSInstantiationExpression<'a>>)
Inherited from Expression
V8IntrinsicExpression(Box<'a, V8IntrinsicExpression<'a>>)
Inherited from Expression
ComputedMemberExpression(Box<'a, ComputedMemberExpression<'a>>)
Inherited from MemberExpression.
MemberExpression[?Yield, ?Await] [ Expression[+In, ?Yield, ?Await] ]
StaticMemberExpression(Box<'a, StaticMemberExpression<'a>>)
Inherited from MemberExpression.
MemberExpression[?Yield, ?Await] . IdentifierName
PrivateFieldExpression(Box<'a, PrivateFieldExpression<'a>>)
Inherited from MemberExpression.
MemberExpression[?Yield, ?Await] . PrivateIdentifier
Implementations
Sourceimpl<'a> PropertyKey<'a>
impl<'a> PropertyKey<'a>
Sourcepub fn is_member_expression(&self) -> bool
pub fn is_member_expression(&self) -> bool
Return if a PropertyKey is a MemberExpression.
Sourcepub fn into_member_expression(self) -> MemberExpression<'a>
pub fn into_member_expression(self) -> MemberExpression<'a>
Sourcepub fn as_member_expression(&self) -> Option<&MemberExpression<'a>>
pub fn as_member_expression(&self) -> Option<&MemberExpression<'a>>
Convert &PropertyKey to &MemberExpression.
Sourcepub fn as_member_expression_mut(&mut self) -> Option<&mut MemberExpression<'a>>
pub fn as_member_expression_mut(&mut self) -> Option<&mut MemberExpression<'a>>
Convert &mut PropertyKey to &mut MemberExpression.
Sourcepub fn to_member_expression(&self) -> &MemberExpression<'a>
pub fn to_member_expression(&self) -> &MemberExpression<'a>
Sourcepub fn to_member_expression_mut(&mut self) -> &mut MemberExpression<'a>
pub fn to_member_expression_mut(&mut self) -> &mut MemberExpression<'a>
Sourceimpl<'a> PropertyKey<'a>
impl<'a> PropertyKey<'a>
Sourcepub fn is_expression(&self) -> bool
pub fn is_expression(&self) -> bool
Return if a PropertyKey is a Expression.
Sourcepub fn into_expression(self) -> Expression<'a>
pub fn into_expression(self) -> Expression<'a>
Sourcepub fn as_expression(&self) -> Option<&Expression<'a>>
pub fn as_expression(&self) -> Option<&Expression<'a>>
Convert &PropertyKey to &Expression.
Sourcepub fn as_expression_mut(&mut self) -> Option<&mut Expression<'a>>
pub fn as_expression_mut(&mut self) -> Option<&mut Expression<'a>>
Convert &mut PropertyKey to &mut Expression.
Sourcepub fn to_expression(&self) -> &Expression<'a>
pub fn to_expression(&self) -> &Expression<'a>
Sourcepub fn to_expression_mut(&mut self) -> &mut Expression<'a>
pub fn to_expression_mut(&mut self) -> &mut Expression<'a>
Sourceimpl<'a> PropertyKey<'a>
impl<'a> PropertyKey<'a>
Sourcepub fn static_name(&self) -> Option<Cow<'a, str>>
pub fn static_name(&self) -> Option<Cow<'a, str>>
Returns the static name of this property, if it has one, or None otherwise.
Example
a: 1in{ a: 1 }would returna#a: 1inclass C { #a: 1 }would returnNone'a': 1in{ 'a': 1 }would returna[a]: 1in{ [a]: 1 }would returnNone
Sourcepub fn is_specific_static_name(&self, name: &str) -> bool
pub fn is_specific_static_name(&self, name: &str) -> bool
Returns true if the static name of this property key is exactly equal to the given name.
Sourcepub fn is_identifier(&self) -> bool
pub fn is_identifier(&self) -> bool
Returns true if this property key is an identifier, such as a in { a: 1 } or
#a in class C { #a: 1 }.
Sourcepub fn is_private_identifier(&self) -> bool
pub fn is_private_identifier(&self) -> bool
Returns true if this property key is a private identifier, such as #a in
class C { #a: 1 }.
Sourcepub fn private_name(&self) -> Option<Atom<'a>>
pub fn private_name(&self) -> Option<Atom<'a>>
Returns the name of this property key, if it is a private identifier, or None otherwise.
Example
#a: 1inclass C { #a: 1 }would returnaa: 1in{ a: 1 }would returnNone
Sourcepub fn name(&self) -> Option<Cow<'a, str>>
pub fn name(&self) -> Option<Cow<'a, str>>
Returns the name of this property key if it is an identifier or literal value, or None otherwise.
Example
#a: 1inclass C { #a: 1 }would returnaa: 1in{ a: 1 }would returna'a': 1in{ 'a': 1 }would returna[a]: 1in{ [a]: 1 }would returnNone
Sourcepub fn is_specific_id(&self, name: &str) -> bool
pub fn is_specific_id(&self, name: &str) -> bool
Returns true if this property key is exactly equal to the given identifier name.
Sourcepub fn is_specific_string_literal(&self, string: &str) -> bool
pub fn is_specific_string_literal(&self, string: &str) -> bool
Returns true if this property key is a string literal with the given value.