#[repr(C)]pub struct Comment {
pub span: Span,
pub attached_to: u32,
pub kind: CommentKind,
pub position: CommentPosition,
pub newlines: CommentNewlines,
pub content: CommentContent,
}Expand description
A comment in source code.
Fields
span: SpanThe span of the comment text, with leading and trailing delimiters.
attached_to: u32Start of token this leading comment is attached to.
/* Leading */ token
^ This start
NOTE: Trailing comment attachment is not computed yet.
kind: CommentKindLine or block comment
position: CommentPositionLeading or trailing comment
newlines: CommentNewlinesWhether this comment has newlines around it. Used to avoid becoming a trailing comment in codegen.
content: CommentContentContent of the comment
Implementations
Sourceimpl Comment
impl Comment
Sourcepub fn new(start: u32, end: u32, kind: CommentKind) -> Comment
pub fn new(start: u32, end: u32, kind: CommentKind) -> Comment
Create a line or block comment at a given location.
Sourcepub fn content_span(&self) -> Span
pub fn content_span(&self) -> Span
Gets the span of the comment content.
Sourcepub fn is_leading(self) -> bool
pub fn is_leading(self) -> bool
Returns true if this comment is before a token.
Sourcepub fn is_trailing(self) -> bool
pub fn is_trailing(self) -> bool
Returns true if this comment is after a token.
Sourcepub fn is_annotation(self) -> bool
pub fn is_annotation(self) -> bool
Is comment with special meaning.
Sourcepub fn is_jsdoc(self) -> bool
pub fn is_jsdoc(self) -> bool
Returns true if this comment is a JSDoc comment. Implies is_leading and is_block.
Sourcepub fn is_legal(self) -> bool
pub fn is_legal(self) -> bool
Legal comments
A “legal comment” is considered to be any statement-level comment
that contains @license or @preserve or that starts with //! or /*!.
Sourcepub fn is_no_side_effects(self) -> bool
pub fn is_no_side_effects(self) -> bool
Is /* @__NO_SIDE_EFFECTS__*/.
Sourcepub fn is_webpack(self) -> bool
pub fn is_webpack(self) -> bool
Is webpack magic comment.
Sourcepub fn is_coverage_ignore(self) -> bool
pub fn is_coverage_ignore(self) -> bool
Is coverage ignore comment.
Sourcepub fn preceded_by_newline(self) -> bool
pub fn preceded_by_newline(self) -> bool
Returns true if this comment is preceded by a newline.
Sourcepub fn followed_by_newline(self) -> bool
pub fn followed_by_newline(self) -> bool
Returns true if this comment is followed by a newline.
Sourcepub fn set_preceded_by_newline(&mut self, preceded_by_newline: bool)
pub fn set_preceded_by_newline(&mut self, preceded_by_newline: bool)
Sets the state of newlines to include/exclude a newline before the comment.
Sourcepub fn set_followed_by_newline(&mut self, followed_by_newline: bool)
pub fn set_followed_by_newline(&mut self, followed_by_newline: bool)
Sets the state of newlines to include/exclude a newline after the comment.